JIC Image Library
=================

.. image:: https://badge.fury.io/py/jicimagelib.svg
   :target: http://badge.fury.io/py/jicimagelib
   :alt: PyPi package

**This Python package is no longer under active development!**

It has been superseded by: https://github.com/JIC-CSB/jicbioimage
